@@ -33,6 +33,7 @@ import zmq as _zmq
 import gevent.event
 import gevent.core
 import sys
+import errno
 
 class Context(_zmq.Context):
 
@@ -47,17 +48,21 @@ class Socket(_zmq.Socket):
     def __init__(self, context, socket_type):
         super(Socket, self).__init__(context, socket_type)
         on_state_changed_fd = self.getsockopt(_zmq.FD)
-        self._readable = gevent.event.Event()
-        self._writable = gevent.event.Event()
+        # NOTE: pyzmq 13.0.0 messed up with setattr (they turned it into a
+        # non-op) and you can't assign attributes normally anymore, hence the
+        # tricks with self.__dict__ here
+        self.__dict__["_readable"] = gevent.event.Event()
+        self.__dict__["_writable"] = gevent.event.Event()
         try:
             # gevent>=1.0
-            self._state_event = gevent.hub.get_hub().loop.io(
-                on_state_changed_fd, gevent.core.READ)
+            self.__dict__["_state_event"] = gevent.hub.get_hub().loop.io(
+                    on_state_changed_fd, gevent.core.READ)
             self._state_event.start(self._on_state_changed)
         except AttributeError:
             # gevent<1.0
-            self._state_event = gevent.core.read_event(on_state_changed_fd,
-                    self._on_state_changed, persist=True)
+            self.__dict__["_state_event"] = \
+                    gevent.core.read_event(on_state_changed_fd,
+                            self._on_state_changed, persist=True)
 
     def _on_state_changed(self, event=None, _evtype=None):
         if self.closed:
@@ -100,7 +105,7 @@ class Socket(_zmq.Socket):
                 self._on_state_changed()
                 return msg
             except _zmq.ZMQError, e:
-                if e.errno != _zmq.EAGAIN:
+                if e.errno not in (_zmq.EAGAIN, errno.EINTR):
                     raise
             self._writable.clear()
             # The following sleep(0) force gevent to switch out to another
@@ -136,7 +141,7 @@ class Socket(_zmq.Socket):
                 self._on_state_changed()
                 return msg
             except _zmq.ZMQError, e:
-                if e.errno != _zmq.EAGAIN:
+                if e.errno not in (_zmq.EAGAIN, errno.EINTR):
                     raise
             self._readable.clear()
             # The following sleep(0) force gevent to switch out to another
